@@ -1,4 +1,4 @@
-/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
+
 /***************************************************************************
  *  GConfKeys.cs
  *
@@ -63,5 +63,6 @@ namespace Banshee.Base
         public const string TrackPropertiesExpanded = BasePath + "TrackPropertiesExpanded";
         public const string EnableSpecialKeys = BasePath + "EnableSpecialKeys";
         public const string ShowCoverArt = BasePath + "ShowCoverArt";
+        public const string ShowInitialImportDialog = BasePath + "ShowInitialImportDialog";
     }
 }
