@@ -65,8 +65,6 @@ namespace Banshee
         private VolumeButton volumeButton;
         private PlaylistView playlistView;
         private SourceView sourceView;
-        private TrackInfo activeTrackInfo;
-        private NotificationAreaIconContainer trayIcon;
         private ImageAnimation spinner;
         private TrackInfoHeader trackInfoHeader;
         private CoverArtView cover_art_view;
@@ -137,22 +135,17 @@ namespace Banshee
         {
             gxml = new Glade.XML(null, "banshee.glade", "WindowPlayer", null);
             gxml.Autoconnect(this);
-            
+            InterfaceElements.MainWindow = WindowPlayer;
+
             ResizeMoveWindow();
             BuildWindow();   
-            InstallTrayIcon();
             
             Globals.DBusRemote = new DBusRemote();
             banshee_dbus_object = new RemotePlayer(Window, this);
             Globals.DBusRemote.RegisterObject(banshee_dbus_object, "Player");
             
-            PlayerEngineCore.ActivePlayer.Iterate += OnPlayerTick;
-            PlayerEngineCore.ActivePlayer.EndOfStream += OnPlayerEos;    
-            
-            if(PlayerEngineCore.ActivePlayer != PlayerEngineCore.AudioCdPlayer) {
-                PlayerEngineCore.AudioCdPlayer.Iterate += OnPlayerTick;
-                PlayerEngineCore.AudioCdPlayer.EndOfStream += OnPlayerEos;    
-            }
+            PlayerEngineCore.EventChanged += OnPlayerEngineEventChanged;
+            PlayerEngineCore.StateChanged += OnPlayerEngineStateChanged;
             
             if(Globals.AudioCdCore != null) {
                 Globals.AudioCdCore.DiskRemoved += OnAudioCdCoreDiskRemoved;
@@ -192,6 +185,9 @@ namespace Banshee
             WindowPlayer.AddAccelGroup(Globals.ActionManager.UI.AccelGroup);
             
             LoadSettings();
+            
+            Globals.UIManager.SourceViewContainer = gxml["SourceViewContainer"] as Box;
+            Globals.UIManager.Initialize();
         }
    
         private bool InitialLoadTimeout()
@@ -452,7 +448,6 @@ namespace Banshee
             gxml["SearchLabel"].Sensitive = false;
             searchEntry.Sensitive = false;
                 
-                
             toolTips = new Tooltips();
             
             SetTip(burn_button, Catalog.GetString("Write selection to CD"));
@@ -476,25 +471,6 @@ namespace Banshee
             toolTips.SetTip(widget, tip, tip);
         }
           
-        private void InstallTrayIcon()
-        {
-            try {
-                if(!(bool)Globals.Configuration.Get(GConfKeys.ShowNotificationAreaIcon)) {
-                    return;
-                }
-            } catch(Exception) { }
-                
-            try {
-                trayIcon = new NotificationAreaIconContainer();
-                trayIcon.ClickEvent += OnTrayClick;
-                trayIcon.MouseScrollEvent += OnTrayScroll;
-            } catch(Exception e) {
-                trayIcon = null;
-                LogCore.Instance.PushWarning(Catalog.GetString("Notification Area Icon could not be installed"),
-                    e.Message, false);
-            }
-        }
-    
         private void LoadSettings()
         {    
             try {
@@ -503,10 +479,7 @@ namespace Banshee
                 volumeButton.Volume = 80;
             }
 
-            PlayerEngineCore.ActivePlayer.Volume = (ushort)volumeButton.Volume;
-            if(PlayerEngineCore.AudioCdPlayer != PlayerEngineCore.ActivePlayer) {
-                PlayerEngineCore.AudioCdPlayer.Volume = (ushort)volumeButton.Volume;
-            }
+            PlayerEngineCore.Volume = (ushort)volumeButton.Volume;
             
             try {
                 int state = (int)Globals.Configuration.Get(GConfKeys.PlaylistRepeat);
@@ -664,7 +637,7 @@ namespace Banshee
         {
             ActiveUserEventsManager.Instance.CancelAll();
             playlistView.Shutdown();
-            PlayerEngineCore.ActivePlayer.Dispose();
+            PlayerEngineCore.Dispose();
             Globals.Configuration.Set(GConfKeys.SourceViewWidth, SourceSplitter.Position);
             Globals.DBusRemote.UnregisterObject(banshee_dbus_object);
             PlayerCore.Dispose();
@@ -676,92 +649,32 @@ namespace Banshee
         {
             LabelInfo.Markup = "<span size=\"small\">" + GLib.Markup.EscapeText(text) + "</span>";
         }
-          
-        public void TogglePlaying()
-        {
-            if(PlayerEngineCore.ActivePlayer.Playing) {
-                Globals.ActionManager.UpdateAction("PlayPauseAction", Catalog.GetString("Play"), 
-                    "media-playback-start");
-                PlayerEngineCore.ActivePlayer.Pause();
-            } else {
-                Globals.ActionManager.UpdateAction("PlayPauseAction", Catalog.GetString("Pause"), 
-                    "media-playback-pause");
-                PlayerEngineCore.ActivePlayer.Play();
-            }
-        }
         
-        public void UpdateMetaDisplay(TrackInfo ti)
+        public void UpdateMetaDisplay()
         {
-            if(ti == null) {
+            TrackInfo track = PlayerEngineCore.CurrentTrack;
+            
+            if(track == null) {
                 WindowPlayer.Title = Catalog.GetString("Banshee Music Player");
                 trackInfoHeader.Visible = false;
-                if(trayIcon != null) {
-                    trayIcon.Track = null;
-                }
                 return;
             }
         
-            trackInfoHeader.Artist = ti.DisplayArtist;
-            trackInfoHeader.Title = ti.DisplayTitle;
-            trackInfoHeader.Album = ti.DisplayAlbum;
+            trackInfoHeader.Artist = track.DisplayArtist;
+            trackInfoHeader.Title = track.DisplayTitle;
+            trackInfoHeader.Album = track.DisplayAlbum;
             
             trackInfoHeader.Visible = true;
             
-            WindowPlayer.Title = ti.DisplayTitle + " (" + ti.DisplayArtist + ")";
+            WindowPlayer.Title = track.DisplayTitle + " (" + track.DisplayArtist + ")";
             
             try {
-                trackInfoHeader.Cover.FileName = ti.CoverArtFileName;
-                cover_art_view.FileName = ti.CoverArtFileName;
-                trackInfoHeader.Cover.Label = String.Format("{0} - {1}", ti.Artist, ti.Album);
+                trackInfoHeader.Cover.FileName = track.CoverArtFileName;
+                cover_art_view.FileName = track.CoverArtFileName;
+                trackInfoHeader.Cover.Label = String.Format("{0} - {1}", track.DisplayArtist, track.DisplayAlbum);
             } catch(Exception) {
             }
             
-            if(trayIcon != null) {
-                trayIcon.Track = ti;
-            }
-        }
-        
-        public void PlayFile(TrackInfo ti)
-        {
-            PlayerEngineCore.ActivePlayer.Close();
-            
-            if(ti.Uri == null) {
-                return;
-            }
-            
-            if(ti.Uri.Scheme == "cdda") {
-                PlayerEngineCore.LoadCdPlayer();
-            } else {
-                if(ti.Uri != null) {
-                    string ext = ti.Uri.AbsoluteUri.Substring(ti.Uri.AbsoluteUri.LastIndexOf('.') + 1);
-                    PlayerEngineCore.LoadEngineByExtension(ext);
-                } else {
-                    PlayerEngineCore.UnloadCdPlayer();
-                }
-            }
-            
-            activeTrackInfo = ti;
-            PlayerEngineCore.ActivePlayer.Open(ti, ti.Uri);
-
-            incrementedCurrentSongPlayCount = false;
-            ScaleTime.Adjustment.Lower = 0;
-            ScaleTime.Adjustment.Upper = ti.Duration.TotalSeconds;
-
-            UpdateMetaDisplay(ti);
-            
-            TogglePlaying();
-
-            playlistView.QueueDraw();
-            
-            if(!ti.CanPlay) {
-                LogCore.Instance.PushWarning(
-                    Catalog.GetString("Cannot Play Song"), 
-                    String.Format(Catalog.GetString("{0} cannot be played by Banshee. " +
-                        "The most common reasons for this are:\n\n" +
-                        "  <big>\u2022</big> Song is protected (DRM)\n" +
-                        "  <big>\u2022</big> Song is on a DAP that does not support playback\n"),
-                        ti.Title));
-            }
         }
         
         // ---- Window Event Handlers ----
@@ -808,16 +721,16 @@ namespace Banshee
                     break;
                 case Gdk.Key.Left:
                     if((args.Event.State & Gdk.ModifierType.ControlMask) != 0) {
-                        PlayerEngineCore.ActivePlayer.Position -= SkipDelta;
+                        PlayerEngineCore.Position -= SkipDelta;
                         handled = true;
                     } else if((args.Event.State & Gdk.ModifierType.ShiftMask) != 0) {
-                        PlayerEngineCore.ActivePlayer.Position = 0;
+                        PlayerEngineCore.Position = 0;
                         handled = true;
                     }
                     break;
                 case Gdk.Key.Right:
                     if((args.Event.State & Gdk.ModifierType.ControlMask) != 0) {
-                        PlayerEngineCore.ActivePlayer.Position += SkipDelta;
+                        PlayerEngineCore.Position += SkipDelta;
                         handled = true;
                     } 
                     break;
@@ -843,58 +756,20 @@ namespace Banshee
             }
         }       
               
-        // ---- Tray Event Handlers ----
-      
-        private void OnTrayClick(object o, EventArgs args)
-        {
-            WindowPlayer.Visible = !WindowPlayer.Visible;
-            ResizeMoveWindow();
-        }
-          
-        private void OnTrayScroll(object o, ScrollEventArgs args)
-        {
-            switch(args.Event.Direction) {
-                case Gdk.ScrollDirection.Up:
-                    if((args.Event.State & Gdk.ModifierType.ControlMask) != 0) {            
-                        Volume += VolumeDelta;
-                    } else if((args.Event.State & Gdk.ModifierType.ShiftMask) != 0) {
-                        PlayerEngineCore.ActivePlayer.Position += SkipDelta;
-                    } else {
-                        Next();
-                    }
-                    break;
-                case Gdk.ScrollDirection.Down:
-                    if((args.Event.State & Gdk.ModifierType.ControlMask) != 0) {            
-                        Volume -= VolumeDelta;
-                    } else if((args.Event.State & Gdk.ModifierType.ShiftMask) != 0) {
-                        PlayerEngineCore.ActivePlayer.Position -= SkipDelta;
-                    } else {
-                        Previous();
-                    }
-                    break;
-                default:
-                    break;
-            }
-        }
-   
-        public int Volume {
-            get {
-                return volumeButton.Volume;
-            }
-            
-            set {
-                if(value != volumeButton.Volume) {
-                    volumeButton.Volume = Math.Max(0, Math.Min(100, value));
-                    OnVolumeScaleChanged(volumeButton.Volume);
-                }
-            }
-        }
-   
         // ---- Playback Event Handlers ----
         
+        public void TogglePlaying()
+        {
+            if(PlayerEngineCore.CurrentState == PlayerEngineState.Playing) {
+                PlayerEngineCore.Pause();
+            } else {
+                PlayerEngineCore.Play();
+            }
+        }
+        
         public void PlayPause()
         {
-            if(PlayerEngineCore.ActivePlayer.Loaded) {
+            if(PlayerEngineCore.CurrentState != PlayerEngineState.Idle) {
                 TogglePlaying();
             } else {
                 if(!playlistView.PlaySelected()) {
@@ -918,7 +793,7 @@ namespace Banshee
          
         private void OnVolumeScaleChanged(int volume)
         {
-            PlayerEngineCore.ActivePlayer.Volume = (ushort)volume;
+            PlayerEngineCore.Volume = (ushort)volume;
             Globals.Configuration.Set(GConfKeys.Volume, volume);
         }
    
@@ -926,7 +801,7 @@ namespace Banshee
         
         private void SetPositionLabel(long position)
         {
-            if(activeTrackInfo == null) {
+            if(PlayerEngineCore.CurrentTrack == null) {
                 return;
             }
             
@@ -934,54 +809,106 @@ namespace Banshee
                 // Translators: position in song. eg, "0:37 of 3:48"
                 String.Format(Catalog.GetString("{0} of {1}"),
                           String.Format("{0}:{1:00}", position / 60, position % 60),
-                          String.Format("{0}:{1:00}", activeTrackInfo.Duration.Minutes, 
-                          activeTrackInfo.Duration.Seconds))
+                          String.Format("{0}:{1:00}", PlayerEngineCore.CurrentTrack.Duration.Minutes, 
+                          PlayerEngineCore.CurrentTrack.Duration.Seconds))
             );    
         }
         
-        private void OnPlayerTick(object o, PlayerEngineIterateArgs args)
+        private void OnPlayerEngineStateChanged(object o, PlayerEngineStateArgs args)
         {
-            if(activeTrackInfo == null) {
+            switch(args.State) {
+                case PlayerEngineState.Loaded:
+                    incrementedCurrentSongPlayCount = false;
+                    ScaleTime.Adjustment.Lower = 0;
+                    ScaleTime.Adjustment.Upper = PlayerEngineCore.CurrentTrack.Duration.TotalSeconds;
+                    
+                    UpdateMetaDisplay();
+                    playlistView.QueueDraw();
+                    
+                    if(!PlayerEngineCore.CurrentTrack.CanPlay) {
+                        LogCore.Instance.PushWarning(
+                            Catalog.GetString("Cannot Play Song"), 
+                            String.Format(Catalog.GetString("{0} cannot be played by Banshee. " +
+                                "The most common reasons for this are:\n\n" +
+                                "  <big>\u2022</big> Song is protected (DRM)\n" +
+                                "  <big>\u2022</big> Song is on a DAP that does not support playback\n"),
+                                PlayerEngineCore.CurrentTrack.Title));
+                    }
+                    
+                    break;
+                case PlayerEngineState.Idle:
+                    Globals.ActionManager.UpdateAction("PlayPauseAction", Catalog.GetString("Play"), "media-playback-start");
+                    ScaleTime.Adjustment.Lower = 0;
+                    ScaleTime.Adjustment.Upper = 0;
+                    ScaleTime.Value = 0;
+                    SetInfoLabel(Catalog.GetString("Idle"));
+                    trackInfoHeader.SetIdle();
+                    
+                    UpdateMetaDisplay();
+                    
+                    break;
+                case PlayerEngineState.Paused:
+                    Globals.ActionManager.UpdateAction("PlayPauseAction", Catalog.GetString("Play"), 
+                        "media-playback-start");
+                    break;
+                case PlayerEngineState.Playing:
+                    Globals.ActionManager.UpdateAction("PlayPauseAction", Catalog.GetString("Pause"), 
+                        "media-playback-pause");
+                    break;
+            }
+        }
+        
+        private void OnPlayerEngineEventChanged(object o, PlayerEngineEventArgs args)
+        {
+            switch(args.Event) {
+                case PlayerEngineEvent.Iterate:
+                    OnPlayerEngineTick();
+                    break;
+                case PlayerEngineEvent.EndOfStream:
+                    playlistModel.Continue();
+                    playlistView.UpdateView();
+                    break;
+                case PlayerEngineEvent.Volume:
+                    volumeButton.Volume = PlayerEngineCore.Volume;
+                    break;
+            }
+        }
+        
+        private void OnPlayerEngineTick()
+        {
+            if(PlayerEngineCore.CurrentTrack == null) {
                 return;
             }
              
-            if(PlayerEngineCore.ActivePlayer.Length > 0 
-                && activeTrackInfo.Duration.TotalSeconds <= 0.0) {
-                activeTrackInfo.Duration = new TimeSpan(PlayerEngineCore.ActivePlayer.Length * TimeSpan.TicksPerSecond);
-                activeTrackInfo.Save();
-                playlistView.ThreadedQueueDraw();
-                ScaleTime.Adjustment.Upper = activeTrackInfo.Duration.TotalSeconds;
+            if(PlayerEngineCore.Length > 0 && PlayerEngineCore.CurrentTrack.Duration.TotalSeconds <= 0.0) {
+                PlayerEngineCore.CurrentTrack.Duration = new TimeSpan(PlayerEngineCore.Length * TimeSpan.TicksPerSecond);
+                PlayerEngineCore.CurrentTrack.Save();
+                playlistView.QueueDraw();
+                ScaleTime.Adjustment.Upper = PlayerEngineCore.CurrentTrack.Duration.TotalSeconds;
             }
                 
-            if(PlayerEngineCore.ActivePlayer.Length > 0 && 
-                PlayerEngineCore.ActivePlayer.Position > PlayerEngineCore.ActivePlayer.Length / 2
+            if(PlayerEngineCore.Length > 0 && PlayerEngineCore.Position > PlayerEngineCore.Length / 2
                 && !incrementedCurrentSongPlayCount) {
-                activeTrackInfo.IncrementPlayCount();
+                PlayerEngineCore.CurrentTrack.IncrementPlayCount();
                 incrementedCurrentSongPlayCount = true;
-                playlistView.ThreadedQueueDraw();
+                playlistView.QueueDraw();
             }
                 
             if(updateEnginePosition) {
-                if(setPositionTimeoutId > 0)
-                        GLib.Source.Remove(setPositionTimeoutId);
-                setPositionTimeoutId = GLib.Timeout.Add(100,
-                        new GLib.TimeoutHandler(SetPositionTimeoutCallback));
+                if(setPositionTimeoutId > 0) {
+                    GLib.Source.Remove(setPositionTimeoutId);
+                }
+                
+                setPositionTimeoutId = GLib.Timeout.Add(100, new GLib.TimeoutHandler(SetPositionTimeoutCallback));
             
-                Application.Invoke(delegate {
-                    SetPositionLabel(args.Position);
-                    if(PlayerEngineCore.ActivePlayer.Playing) {
-                        trayIcon.Update();
-                    }
-                });
+                SetPositionLabel(PlayerEngineCore.Position);
             }
         }
         
         private bool SetPositionTimeoutCallback()
         {
             setPositionTimeoutId = 0;
-            Application.Invoke(delegate {
-                ScaleTime.Value = PlayerEngineCore.ActivePlayer.Position;
-            });
+            ScaleTime.Value = PlayerEngineCore.Position;
             
             return false;
         }
@@ -1003,20 +930,10 @@ namespace Banshee
         private void OnScaleTimeButtonReleaseEvent(object o, 
             ButtonReleaseEventArgs args)
         {
-            PlayerEngineCore.ActivePlayer.Position = (uint)ScaleTime.Value;
+            PlayerEngineCore.Position = (uint)ScaleTime.Value;
             updateEnginePosition = true;
         }
         
-        private void OnPlayerEos(object o, EventArgs args)
-        {
-            Application.Invoke(delegate {
-                StopPlaying();
-                playlistModel.Continue();
-                playlistView.UpdateView();
-            
-            });
-        }
-        
         // ---- Playlist Event Handlers ----
         
         private void OnPlaylistObjectUpdated(object o, EventArgs args)
@@ -1158,9 +1075,14 @@ namespace Banshee
             
             if(source is DapSource) {
                 DapSource dapSource = source as DapSource;
-                Globals.ActionManager["SyncDapAction"].Sensitive = !dapSource.Device.IsReadOnly;
-                Globals.ActionManager.SetActionLabel("SyncDapAction", String.Format("{0} {1}",
-                    Catalog.GetString("Synchronize"), dapSource.Device.GenericName));
+                if (dapSource.Device.CanSynchronize) {
+                    Globals.ActionManager["SyncDapAction"].Sensitive = !dapSource.Device.IsReadOnly;
+                    Globals.ActionManager.SetActionLabel("SyncDapAction", String.Format("{0} {1}",
+                        Catalog.GetString("Synchronize"), dapSource.Device.GenericName));
+                } else {
+                    Globals.ActionManager["SyncDapAction"].Visible = false;
+                }
+
                 Globals.ActionManager["RenameSourceAction"].Label = Catalog.GetString("Rename Device");
             } else {
                 Globals.ActionManager["RenameSourceAction"].Label = Catalog.GetString("Rename Playlist");            
@@ -1359,8 +1281,8 @@ namespace Banshee
 
         private void OnPlaylistStopped(object o, EventArgs args)
         {
-            PlayerEngineCore.ActivePlayer.Close();
-            UpdateMetaDisplay(null);
+            PlayerEngineCore.Close();
+            UpdateMetaDisplay();
         }
 
         private void OnPlaylistUpdated(object o, EventArgs args)
@@ -1897,11 +1819,11 @@ namespace Banshee
             if(source.CanEject) {
                 try {
                     if(source.GetType() == typeof(DapSource)) {
-                        if(activeTrackInfo != null && activeTrackInfo is DapTrackInfo) {
-                            StopPlaying();
+                        if(PlayerEngineCore.CurrentTrack != null && PlayerEngineCore.CurrentTrack is DapTrackInfo) {
+                            PlayerEngineCore.Close();
                         }
                     }
-                        
+                    
                     source.Eject();
                     
                     if(source == SourceManager.ActiveSource) {
@@ -1915,30 +1837,7 @@ namespace Banshee
                 }
             }
         }
-        
-        private void StopPlaying()
-        {
-            PlayerEngineCore.ActivePlayer.Close();
-            Globals.ActionManager.UpdateAction("PlayPauseAction", Catalog.GetString("Play"), "media-playback-start");
-            ScaleTime.Adjustment.Lower = 0;
-            ScaleTime.Adjustment.Upper = 0;
-            ScaleTime.Value = 0;
-            SetInfoLabel(Catalog.GetString("Idle"));
-            trackInfoHeader.SetIdle();
-            activeTrackInfo = null;
-            
-            if(trayIcon != null) {
-                trayIcon.Track = null;
-            }
-        }
-
-        public TrackInfo ActiveTrackInfo
-        {
-            get {
-                return activeTrackInfo;
-            }
-        }
-        
+       
         private void OnImportManagerImportRequested(object o, ImportEventArgs args)
         {
             try {
@@ -2096,6 +1995,25 @@ namespace Banshee
             PromptForImport(false);
         }
         
+        private void OnOpenLocationAction(object o, EventArgs args)
+        {
+            Banshee.Gui.OpenLocationDialog dialog = new Banshee.Gui.OpenLocationDialog();
+            ResponseType response = dialog.Run();
+            string address = dialog.Address;
+            dialog.Destroy();
+            
+            if(response != ResponseType.Ok) {
+                return;
+            }
+            
+            try {
+                PlayerEngineCore.Open(new Uri(address));
+                PlayerEngineCore.Play();
+            } catch(Exception) {
+                Console.WriteLine("BAOSJFDL");
+            }   
+        }
+        
         private void OnImportSourceAction(object o, EventArgs args)
         {
             if(sourceView.HighlightedSource is IImportSource) {
@@ -2305,10 +2223,10 @@ namespace Banshee
         
         private void OnPreviousAction(object o, EventArgs args)
         {
-            if(PlayerEngineCore.ActivePlayer.Position < 3) {
+            if(PlayerEngineCore.Position < 3) {
                 Previous();
             } else {
-                PlayerEngineCore.ActivePlayer.Position = 0;
+                PlayerEngineCore.Position = 0;
             }
         }
         
@@ -2319,12 +2237,12 @@ namespace Banshee
         
         private void OnSeekForwardAction(object o, EventArgs args)
         {
-            PlayerEngineCore.ActivePlayer.Position += SkipDelta;
+            PlayerEngineCore.Position += SkipDelta;
         }
         
         private void OnSeekBackwardAction(object o, EventArgs args)
         {
-            PlayerEngineCore.ActivePlayer.Position -= SkipDelta;
+            PlayerEngineCore.Position -= SkipDelta;
         }
         
         private void SetRepeatMode(RepeatMode mode)
